import { RemovalPolicy } from 'aws-cdk-lib';
import { GatewayVpcEndpoint, Vpc } from 'aws-cdk-lib/aws-ec2';
import { Key } from 'aws-cdk-lib/aws-kms';
import { Construct } from 'constructs';
/**
 * @internal
 * @param {Vpc} vpc the vpc created by the function vpcBootstrap
 * @param {GatewayVpcEndpoint} s3GatewayVpcEndpoint the vpc endpoint attached to the vpc the function vpcBootstrap created
*/
export interface NetworkConfiguration {
    readonly vpc: Vpc;
    readonly s3GatewayVpcEndpoint: GatewayVpcEndpoint;
}
/**
 * @internal
 * Create a VPC with the provided CIDR and attach to it an Amazon S3 Gateway Vpc Endpoint
 * @param {Construct} scope The scope of the stack where the VPC will be created
 * @param {string} vpcCidr The cidr for vpc
 * @param {Key} logKmsKey The KMS key used to encrypt the VPC flow log
 * @param {RemovalPolicy} vpcFlowlogRemovalPolicy The removal policy for vpc flowlog in cloudwatch log
 * @param {string} eksClusterName The name used to tag the subnet and vpc
 * @param {string} emrAppName The name used to tag the subnet and vpc
 */
export declare function vpcBootstrap(scope: Construct, vpcCidr: string, logKmsKey: Key, vpcFlowlogRemovalPolicy?: RemovalPolicy, eksClusterName?: string, emrAppName?: string): NetworkConfiguration;
